import { SphereGeometry, MathUtils, Mesh, MeshStandardMaterial } from './three.module.js';

function createSphere(color, radius, xOffset, yOffset, zOffset) {

  const widthSegments = 29;
  const heightSegments = 29;
  const geometry = new SphereGeometry(
    radius, widthSegments, heightSegments);

  const material = new MeshStandardMaterial({ color: color, wireframe: true });

  const sphere = new Mesh(geometry, material);

  sphere.position.x = xOffset;
  sphere.position.y = yOffset;
  sphere.position.z = zOffset;

  const radiansPerSecond = MathUtils.degToRad(30);

  // this method will be called once per frame
  sphere.tick = (delta) => {
    // increase the cube's rotation each frame
    sphere.rotation.z += radiansPerSecond * delta;
    sphere.rotation.x += radiansPerSecond * delta;
    sphere.rotation.y += radiansPerSecond * delta;
  };

  return sphere;
}

export { createSphere };
